#libpythonpro
Projeto de estudo do uso do Git, Virtualenv e Pip

[![Updates](https://pyup.io/repos/github/rafarios20/libpythonpro/shield.svg)](https://pyup.io/repos/github/rafarios20/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/rafarios20/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/rafarios20/libpythonpro/)


Para instalar:
```console
python -m venv .venv
.venv\scripts\activate
pip install -r requirements-dev.txt
```

Para rodar:
```console
flake8

```